@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use Carp;
 use Exporter;
@@ -139,9 +139,11 @@ sub splice {
     if ($find){
         $find = qr{$find};
 
-        while (my ($i, $e) = each @contents){
-            if ($e =~ /$find/){
-                splice @contents, ++$i, 0, @$insert;
+        my $i = 0;
+        for (@contents){
+            $i++;
+            if (/$find/){
+                splice @contents, $i, 0, @$insert;
                 last;
             }
         }
